@@ -1,4 +1,4 @@
-// Heatbugs application. Copyright  1996-1999 Santa Fe Institute.
+// Heatbugs application. Copyright  1996-2000 Swarm Development Group.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -126,7 +126,7 @@
 
   // Now go in to the heatbugs in the model and set their colours to green (64)
 
-  [[heatbugModelSwarm getHeatbugList] forEach: M(setBugColor:) : (void *) 64];
+  [[heatbugModelSwarm getHeatbugList] forEach: M(setBugColor:) : (id) 64];
   
   // Next, create a 2d window for display, set its size, zoom factor, title.
   
@@ -199,7 +199,8 @@
 #ifdef SCREENSHOTS
       {
         char filename[40];
-
+#ifndef FULL
+	
         sprintf (filename, "graph%07ld.png", getCurrentTime ());
         [actionCache doTkEvents];
         [[[[[[Pixmap createBegin: self]
@@ -211,6 +212,14 @@
               setWidget: worldRaster]
              setDecorationsFlag: YES]
             createEnd] save: filename] drop];
+#else
+        sprintf (filename, "screen%07ld.png", getCurrentTime ());
+	[actionCache doTkEvents];
+        [[[[[[Pixmap createBegin: self]
+              setWidget: nil]
+	     setDecorationsFlag: NO]
+            createEnd] save: filename] drop];
+#endif
       }
 #endif
     }
