@@ -1,4 +1,4 @@
-// Mousetraps application. Copyright  1996-1999 Santa Fe Institute.
+// Mousetrap application. Copyright  1996-2000 Swarm Development Group.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -25,9 +25,9 @@
 #endif
   id modelSwarm;			// our modelSwarm
 @private
-  id <UniformDouble> uniform0to1;
-  id <UniformInteger> uniformRadius;
-  id <UniformUnsigned> uniformTrigTime;
+  id <UniformDoubleDist> uniform0to1;
+  id <UniformIntegerDist> uniformRadius;
+  id <UniformUnsignedDist> uniformTrigTime;
 }
 
   // Methods that a mousetrap responds to
