@@ -1,4 +1,4 @@
-// Mousetrap application. Copyright  1996-1999 Santa Fe Institute.
+// Mousetrap application. Copyright  1996-2000 Swarm Development Group.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -50,7 +50,7 @@
 
   // if we can't find the right key from the Archiver, raise an event
   if ((mousetrapModelSwarm = 
-       [archiver getWithZone: self object: "modelSwarm"]) == nil)
+       [archiver getWithZone: self key: "modelSwarm"]) == nil)
     raiseEvent(InvalidOperation, 
                "Can't find archiver file or appropriate key");
   
