@@ -1,4 +1,4 @@
-// Mousetraps application. Copyright  1996-1999 Santa Fe Institute.
+// Mousetrap application. Copyright  1996-2000 Swarm Development Group.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -157,12 +157,12 @@
   
   tempObj = [super createEnd];
   
-  randomGenerator = [PMMLCG1 create: [self getZone]
-			     setStateFromSeed: 1234567890];
-  uniform0to1 = [UniformDouble create: [self getZone]
-			       setGenerator: randomGenerator
-			       setDoubleMin: 0.0L
-			       setMax: 1.0L];
+  randomGenerator = [PMMLCG1gen create: [self getZone]
+                                setStateFromSeed: 1234567890];
+  uniform0to1 = [UniformDoubleDist create: [self getZone]
+                                   setGenerator: randomGenerator
+                                   setDoubleMin: 0.0L
+                                   setMax: 1.0L];
   return tempObj;
 }
 
