@@ -1,4 +1,4 @@
-// Mousetrap application. Copyright  1996-1999 Santa Fe Institute.
+// Mousetrap application. Copyright  1996-2000 Swarm Development Group.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -44,7 +44,7 @@ main (int argc, const char **argv)
       // archiver will actually *instantiate* the object if the
       // parameters are found in the Lisp file
       if ((theTopLevelSwarm = 
-           [archiver getWithZone: globalZone object: "batchSwarm"]) == nil)
+           [archiver getWithZone: globalZone key: "batchSwarm"]) == nil)
         raiseEvent(InvalidOperation, 
                    "Can't find archiver file or appropriate key");
       
